@@ -1,4 +1,4 @@
-from my_python_utility import Class2
+from my_python_utility.Class2 import Class2
 
 class Class1:
     def __init__(self, name, age):
